.. _all-salt.proxy:

==================================
Full list of builtin proxy modules
==================================

.. currentmodule:: salt.proxy

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    esxi
    fx2
    junos
    rest_sample
    ssh_sample
